# -*- coding: utf-8 -*-
"""Cisco Catalyst Center EditSensorTestTemplate data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorE2F9718DE3D050819Cdc6355A3A43200(object):
    """EditSensorTestTemplate request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorE2F9718DE3D050819Cdc6355A3A43200, self).__init__()
        self._validator = fastjsonschema.compile(json.loads('''
{
    "$schema": "http://json-schema.org/draft-04/schema#",
    "properties": {
        "_id": {
            "type": "string"
        },
        "actionInProgress": {
            "type": "string"
        },
        "apCoverage": {
            "items": {
                "properties": {
                    "bands": {
                        "type": "string"
                    },
                    "numberOfApsToTest": {
                        "type": "integer"
                    },
                    "rssiThreshold": {
                        "type": "integer"
                    }
                },
                "type": "object"
            },
            "type": "array"
        },
        "connection": {
            "type": "string"
        },
        "encryptionMode": {
            "type": "string"
        },
        "frequency": {
            "properties": {
                "unit": {
                    "type": "string"
                },
                "value": {
                    "type": "integer"
                }
            },
            "type": "object"
        },
        "lastModifiedTime": {
            "type": "integer"
        },
        "location": {
            "type": "string"
        },
        "locationInfoList": {
            "items": {
                "properties": {
                    "allSensors": {
                        "type": "boolean"
                    },
                    "customManagementVlan": {
                        "type": "boolean"
                    },
                    "locationId": {
                        "type": "string"
                    },
                    "locationType": {
                        "type": "string"
                    },
                    "macAddressList": {
                        "items": {
                            "type": "string"
                        },
                        "type": "array"
                    },
                    "managementVlan": {
                        "type": "string"
                    },
                    "siteHierarchy": {
                        "type": "string"
                    }
                },
                "type": "object"
            },
            "type": "array"
        },
        "modelVersion": {
            "type": "integer"
        },
        "name": {
            "type": "string"
        },
        "numAssociatedSensor": {
            "type": "integer"
        },
        "numNeighborAPThreshold": {
            "type": "integer"
        },
        "profiles": {
            "items": {
                "properties": {
                    "authProtocol": {
                        "type": "string"
                    },
                    "authType": {
                        "type": "string"
                    },
                    "certdownloadurl": {
                        "type": "string"
                    },
                    "certfilename": {
                        "type": "string"
                    },
                    "certpassphrase": {
                        "type": "string"
                    },
                    "certstatus": {
                        "type": "string"
                    },
                    "certxferprotocol": {
                        "type": "string"
                    },
                    "deviceType": {
                        "type": "string"
                    },
                    "eapMethod": {
                        "type": "string"
                    },
                    "extWebAuth": {
                        "type": "boolean"
                    },
                    "extWebAuthAccessUrl": {
                        "type": "string"
                    },
                    "extWebAuthHtmlTag": {
                        "items": {
                            "properties": {
                                "label": {
                                    "type": "string"
                                },
                                "tag": {
                                    "type": "string"
                                },
                                "value": {
                                    "type": "string"
                                }
                            },
                            "type": "object"
                        },
                        "type": "array"
                    },
                    "extWebAuthPortal": {
                        "type": "string"
                    },
                    "extWebAuthVirtualIp": {
                        "type": "string"
                    },
                    "locationVlanList": {
                        "items": {
                            "properties": {
                                "locationId": {
                                    "type": "string"
                                },
                                "vlans": {
                                    "items": {
                                        "type": "string"
                                    },
                                    "type": "array"
                                }
                            },
                            "type": "object"
                        },
                        "type": "array"
                    },
                    "password": {
                        "type": "string"
                    },
                    "passwordType": {
                        "type": "string"
                    },
                    "profileName": {
                        "type": "string"
                    },
                    "psk": {
                        "type": "string"
                    },
                    "qosPolicy": {
                        "type": "string"
                    },
                    "scep": {
                        "type": "boolean"
                    },
                    "tests": {
                        "items": {
                            "properties": {
                                "config": {
                                    "items": {
                                        "properties": {
                                            "direction": {
                                                "type": "string"
                                            },
                                            "domains": {
                                                "items": {
                                                    "type": "string"
                                                },
                                                "type": "array"
                                            },
                                            "downlinkTest": {
                                                "type": "boolean"
                                            },
                                            "endPort": {
                                                "type": "integer"
                                            },
                                            "exitCommand": {
                                                "type": "string"
                                            },
                                            "finalPrompt": {
                                                "type": "string"
                                            },
                                            "ndtServer": {
                                                "type": "string"
                                            },
                                            "ndtServerPath": {
                                                "type": "string"
                                            },
                                            "ndtServerPort": {
                                                "type": "string"
                                            },
                                            "numPackets": {
                                                "type": "string"
                                            },
                                            "password": {
                                                "type": "string"
                                            },
                                            "passwordPrompt": {
                                                "type": "string"
                                            },
                                            "pathToDownload": {
                                                "type": "string"
                                            },
                                            "port": {
                                                "type": "integer"
                                            },
                                            "probeType": {
                                                "type": "string"
                                            },
                                            "protocol": {
                                                "type": "string"
                                            },
                                            "proxyPassword": {
                                                "type": "string"
                                            },
                                            "proxyPort": {
                                                "type": "string"
                                            },
                                            "proxyServer": {
                                                "type": "string"
                                            },
                                            "proxyUserName": {
                                                "type": "string"
                                            },
                                            "server": {
                                                "type": "string"
                                            },
                                            "servers": {
                                                "items": {
                                                    "type": "string"
                                                },
                                                "type": "array"
                                            },
                                            "sharedSecret": {
                                                "type": "string"
                                            },
                                            "startPort": {
                                                "type": "integer"
                                            },
                                            "transferType": {
                                                "type": "string"
                                            },
                                            "udpBandwidth": {
                                                "type": "integer"
                                            },
                                            "uplinkTest": {
                                                "type": "boolean"
                                            },
                                            "url": {
                                                "type": "string"
                                            },
                                            "userName": {
                                                "type": "string"
                                            },
                                            "userNamePrompt": {
                                                "type": "string"
                                            }
                                        },
                                        "type": "object"
                                    },
                                    "type": "array"
                                },
                                "name": {
                                    "type": "string"
                                }
                            },
                            "type": "object"
                        },
                        "type": "array"
                    },
                    "username": {
                        "type": "string"
                    },
                    "vlan": {
                        "type": "string"
                    },
                    "whiteList": {
                        "type": "boolean"
                    }
                },
                "type": "object"
            },
            "type": "array"
        },
        "radioAsSensorRemoved": {
            "type": "boolean"
        },
        "rssiThreshold": {
            "type": "integer"
        },
        "runNow": {
            "type": "string"
        },
        "scheduleInDays": {
            "type": "integer"
        },
        "sensors": {
            "items": {
                "properties": {
                    "allSensorAddition": {
                        "type": "boolean"
                    },
                    "assigned": {
                        "type": "boolean"
                    },
                    "configUpdated": {
                        "type": "string"
                    },
                    "hostName": {
                        "type": "string"
                    },
                    "iPerfInfo": {
                        "type": "object"
                    },
                    "id": {
                        "type": "string"
                    },
                    "ipAddress": {
                        "type": "string"
                    },
                    "locationId": {
                        "type": "string"
                    },
                    "macAddress": {
                        "type": "string"
                    },
                    "markedForUninstall": {
                        "type": "boolean"
                    },
                    "name": {
                        "type": "string"
                    },
                    "runNow": {
                        "type": "string"
                    },
                    "sensorType": {
                        "type": "string"
                    },
                    "servicePolicy": {
                        "type": "string"
                    },
                    "status": {
                        "type": "string"
                    },
                    "switchMac": {
                        "type": "string"
                    },
                    "switchSerialNumber": {
                        "type": "string"
                    },
                    "switchUuid": {
                        "type": "string"
                    },
                    "targetAPs": {
                        "items": {
                            "type": "string"
                        },
                        "type": "array"
                    },
                    "testMacAddresses": {
                        "type": "object"
                    },
                    "wiredApplicationMessage": {
                        "type": "string"
                    },
                    "wiredApplicationStatus": {
                        "type": "string"
                    },
                    "xorSensor": {
                        "type": "boolean"
                    }
                },
                "type": "object"
            },
            "type": "array"
        },
        "showWlcUpgradeBanner": {
            "type": "boolean"
        },
        "siteHierarchy": {
            "type": "string"
        },
        "ssids": {
            "items": {
                "properties": {
                    "authProtocol": {
                        "type": "string"
                    },
                    "authType": {
                        "type": "string"
                    },
                    "bands": {
                        "type": "string"
                    },
                    "certdownloadurl": {
                        "type": "string"
                    },
                    "certfilename": {
                        "type": "string"
                    },
                    "certpassphrase": {
                        "type": "string"
                    },
                    "certstatus": {
                        "type": "string"
                    },
                    "certxferprotocol": {
                        "type": "string"
                    },
                    "eapMethod": {
                        "type": "string"
                    },
                    "extWebAuth": {
                        "type": "boolean"
                    },
                    "extWebAuthAccessUrl": {
                        "type": "string"
                    },
                    "extWebAuthHtmlTag": {
                        "items": {
                            "properties": {
                                "label": {
                                    "type": "string"
                                },
                                "tag": {
                                    "type": "string"
                                },
                                "value": {
                                    "type": "string"
                                }
                            },
                            "type": "object"
                        },
                        "type": "array"
                    },
                    "extWebAuthPortal": {
                        "type": "string"
                    },
                    "extWebAuthVirtualIp": {
                        "type": "string"
                    },
                    "id": {
                        "type": "integer"
                    },
                    "layer3webAuthEmailAddress": {
                        "type": "string"
                    },
                    "layer3webAuthpassword": {
                        "type": "string"
                    },
                    "layer3webAuthsecurity": {
                        "type": "string"
                    },
                    "layer3webAuthuserName": {
                        "type": "string"
                    },
                    "numAps": {
                        "type": "integer"
                    },
                    "numSensors": {
                        "type": "integer"
                    },
                    "password": {
                        "type": "string"
                    },
                    "passwordType": {
                        "type": "string"
                    },
                    "profileName": {
                        "type": "string"
                    },
                    "proxyPassword": {
                        "type": "string"
                    },
                    "proxyPort": {
                        "type": "string"
                    },
                    "proxyServer": {
                        "type": "string"
                    },
                    "proxyUserName": {
                        "type": "string"
                    },
                    "psk": {
                        "type": "string"
                    },
                    "qosPolicy": {
                        "type": "string"
                    },
                    "scep": {
                        "type": "boolean"
                    },
                    "ssid": {
                        "type": "string"
                    },
                    "status": {
                        "type": "string"
                    },
                    "tests": {
                        "items": {
                            "properties": {
                                "config": {
                                    "items": {
                                        "properties": {
                                            "direction": {
                                                "type": "string"
                                            },
                                            "domains": {
                                                "items": {
                                                    "type": "string"
                                                },
                                                "type": "array"
                                            },
                                            "downlinkTest": {
                                                "type": "boolean"
                                            },
                                            "endPort": {
                                                "type": "integer"
                                            },
                                            "exitCommand": {
                                                "type": "string"
                                            },
                                            "finalPrompt": {
                                                "type": "string"
                                            },
                                            "ndtServer": {
                                                "type": "string"
                                            },
                                            "ndtServerPath": {
                                                "type": "string"
                                            },
                                            "ndtServerPort": {
                                                "type": "string"
                                            },
                                            "numPackets": {
                                                "type": "string"
                                            },
                                            "password": {
                                                "type": "string"
                                            },
                                            "passwordPrompt": {
                                                "type": "string"
                                            },
                                            "pathToDownload": {
                                                "type": "string"
                                            },
                                            "port": {
                                                "type": "integer"
                                            },
                                            "probeType": {
                                                "type": "string"
                                            },
                                            "protocol": {
                                                "type": "string"
                                            },
                                            "proxyPassword": {
                                                "type": "string"
                                            },
                                            "proxyPort": {
                                                "type": "string"
                                            },
                                            "proxyServer": {
                                                "type": "string"
                                            },
                                            "proxyUserName": {
                                                "type": "string"
                                            },
                                            "server": {
                                                "type": "string"
                                            },
                                            "servers": {
                                                "items": {
                                                    "type": "string"
                                                },
                                                "type": "array"
                                            },
                                            "sharedSecret": {
                                                "type": "string"
                                            },
                                            "startPort": {
                                                "type": "integer"
                                            },
                                            "transferType": {
                                                "type": "string"
                                            },
                                            "udpBandwidth": {
                                                "type": "integer"
                                            },
                                            "uplinkTest": {
                                                "type": "boolean"
                                            },
                                            "url": {
                                                "type": "string"
                                            },
                                            "userName": {
                                                "type": "string"
                                            },
                                            "userNamePrompt": {
                                                "type": "string"
                                            }
                                        },
                                        "type": "object"
                                    },
                                    "type": "array"
                                },
                                "name": {
                                    "type": "string"
                                }
                            },
                            "type": "object"
                        },
                        "type": "array"
                    },
                    "thirdParty": {
                        "properties": {
                            "selected": {
                                "type": "boolean"
                            }
                        },
                        "type": "object"
                    },
                    "username": {
                        "type": "string"
                    },
                    "validFrom": {
                        "type": "integer"
                    },
                    "validTo": {
                        "type": "integer"
                    },
                    "whiteList": {
                        "type": "boolean"
                    },
                    "wlanId": {
                        "type": "integer"
                    },
                    "wlc": {
                        "type": "string"
                    }
                },
                "type": "object"
            },
            "type": "array"
        },
        "startTime": {
            "type": "integer"
        },
        "status": {
            "type": "string"
        },
        "templateName": {
            "type": "string"
        },
        "testScheduleMode": {
            "type": "string"
        },
        "version": {
            "type": "integer"
        },
        "wlans": {
            "items": {
                "type": "string"
            },
            "type": "array"
        }
    },
    "type": "object"
}
'''))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )



# -*- coding: utf-8 -*-
"""Cisco Catalyst Center Restore API wrapper.

Copyright (c) 2026 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from builtins import *  # noqa: F401,F403


from ...restsession import RestSession
from ...utils import (
    apply_path_params,
    check_type,
    dict_from_items_with_values,
    dict_of_str,
)


class Restore(object):
    """Cisco Catalyst Center Restore API (version: 3.1.6.0).

    Wraps the Catalyst Center Restore
    API and exposes the API as native Python
    methods that return native Python objects.

    """

    def __init__(self, session, object_factory, request_validator):
        """Initialize a new Restore
        object with the provided RestSession.

        Args:
            session(RestSession): The RESTful session object to be used for
                API calls to the Catalyst Center service.

        Raises:
            TypeError: If the parameter types are incorrect.

        """
        check_type(session, RestSession)

        super(Restore, self).__init__()

        self._session = session
        self._object_factory = object_factory
        self._request_validator = request_validator

    def restore_backup(
        self,
        id,
        encryptionPassphrase=None,
        headers=None,
        payload=None,
        active_validation=True,
        **request_parameters
    ):
        """This api is used to trigger restore workflow of a specific backup. Obtain the `id` from the id attribute in the
        response of the `/dna/system/api/v1/backups` API. To monitor the progress and completion of the backup
        deletion , please call `/dna/system/api/v1/backupRestoreExecutions/{id}` api , where id is the taskId
        attribute from the response of the curent endpoint.

        Args:
            encryptionPassphrase(string): Restore's Passphrase to restore backup.
            id(str): id path parameter. The `id` of the backup to be restored.Obtain the `id` from the id attribute
                in the response of the `/dna/system/api/v1/backups` API.
            headers(dict): Dictionary of HTTP Headers to send with the Request
                .
            payload(dict): A JSON serializable Python object to send in the
                body of the Request.
            active_validation(bool): Enable/Disable payload validation.
                Defaults to True.
            **request_parameters: Additional request parameters (provides
                support for parameters that may be added in the future).

        Returns:
            MyDict: JSON response. Access the object's properties by using
            the dot notation or the bracket notation.

        Raises:
            TypeError: If the parameter types are incorrect.
            MalformedRequest: If the request body created is invalid.
            ApiError: If the Catalyst Center cloud returns an error.
        Documentation Link:
            https://developer.cisco.com/docs/dna-center/#!restore-backup
        """
        check_type(headers, dict)
        check_type(payload, dict)
        check_type(id, str, may_be_none=False)
        if headers is not None:
            if "Content-Type" in headers:
                check_type(headers.get("Content-Type"), str, may_be_none=False)
            if "X-Auth-Token" in headers:
                check_type(headers.get("X-Auth-Token"), str, may_be_none=False)

        _params = {}
        _params.update(request_parameters)
        _params = dict_from_items_with_values(_params)

        path_params = {
            "id": id,
        }
        _payload = {
            "encryptionPassphrase": encryptionPassphrase,
        }
        _payload.update(payload or {})
        _payload = dict_from_items_with_values(_payload)
        if active_validation:
            self._request_validator(
                "jsd_b5a94fd2d97514b8a9cf73df4e154b8_v3_1_6_0"
            ).validate(_payload)

        with_custom_headers = False
        _headers = self._session.headers or {}
        if headers:
            _headers.update(dict_of_str(headers))
            with_custom_headers = True

        e_url = "/dna/system/api/v1/backups/{id}/restore"
        endpoint_full_url = apply_path_params(e_url, path_params)
        if with_custom_headers:
            json_data = self._session.post(
                endpoint_full_url, params=_params, json=_payload, headers=_headers
            )
        else:
            json_data = self._session.post(
                endpoint_full_url, params=_params, json=_payload
            )

        return self._object_factory(
            "bpm_b5a94fd2d97514b8a9cf73df4e154b8_v3_1_6_0", json_data
        )


# Alias Functions



# -*- coding: utf-8 -*-
"""Cisco DNA Center UpdateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import json
from builtins import *  # noqa: F401,F403

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorEe7664344F50Cb8F2C94Beaa01629D(object):
    """UpdateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
    request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorEe7664344F50Cb8F2C94Beaa01629D, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "cdpGlobalConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "CDP_GLOBAL"
                ],
                "type": "string"
                },
                "holdTime": {
                "type": "integer"
                },
                "isAdvertiseV2Enabled": {
                "type": "boolean"
                },
                "isCdpEnabled": {
                "type": "boolean"
                },
                "isLogDuplexMismatchEnabled": {
                "type": "boolean"
                },
                "timer": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "cdpInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "CDP_INTERFACE"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "isCdpEnabled": {
                "type": "boolean"
                },
                "isLogDuplexMismatchEnabled": {
                "type": "boolean"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "dhcpSnoopingGlobalConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                ""
                ],
                "type": "string"
                },
                "databaseAgent": {
                "properties": {
                "agentUrl": {
                "type": "string"
                },
                "configType": {
                "enum": [
                "DHCP_SNOOPING_DATABASE_AGENT"
                ],
                "type": "string"
                },
                "timeout": {
                "type": "integer"
                },
                "writeDelay": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "dhcpSnoopingVlans": {
                "type": "string"
                },
                "isDhcpSnoopingEnabled": {
                "type": "boolean"
                },
                "isGleaningEnabled": {
                "type": "boolean"
                },
                "proxyBridgeVlans": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "dhcpSnoopingInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "DHCP_SNOOPING_INTERFACE"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "isTrustedInterface": {
                "type": "boolean"
                },
                "messageRateLimit": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "dot1xGlobalConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "authenticationConfigMode": {
                "enum": [
                "LEGACY",
                "NEW_STYLE"
                ],
                "type": "string"
                },
                "configType": {
                "enum": [
                "DOT1X_GLOBAL"
                ],
                "type": "string"
                },
                "isDot1xEnabled": {
                "type": "boolean"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "dot1xInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "authenticationOrder": {
                "properties": {
                "configType": {
                "enum": [
                "ORDERED_SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "type": "string"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "configType": {
                "enum": [
                "DOT1X_INTERFACE"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "igmpSnoopingGlobalConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "IGMP_SNOOPING_GLOBAL"
                ],
                "type": "string"
                },
                "igmpSnoopingVlanSettings": {
                "properties": {
                "configType": {
                "enum": [
                "SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "IGMP_SNOOPING_VLAN"
                ],
                "type": "string"
                },
                "igmpSnoopingVlanMrouters": {
                "properties": {
                "configType": {
                "enum": [
                "SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "IGMP_SNOOPING_VLAN_MROUTER"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "isIgmpSnoopingEnabled": {
                "type": "boolean"
                },
                "isImmediateLeaveEnabled": {
                "type": "boolean"
                },
                "isQuerierEnabled": {
                "type": "boolean"
                },
                "querierAddress": {
                "type": "string"
                },
                "querierQueryInterval": {
                "type": "integer"
                },
                "querierVersion": {
                "enum": [
                "VERSION_1",
                "VERSION_2",
                "VERSION_3"
                ],
                "type": "string"
                },
                "vlanId": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "isIgmpSnoopingEnabled": {
                "type": "boolean"
                },
                "isQuerierEnabled": {
                "type": "boolean"
                },
                "querierAddress": {
                "type": "string"
                },
                "querierQueryInterval": {
                "type": "integer"
                },
                "querierVersion": {
                "enum": [
                "VERSION_1",
                "VERSION_2",
                "VERSION_3"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "lldpGlobalConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "LLDP_GLOBAL"
                ],
                "type": "string"
                },
                "holdTime": {
                "type": "integer"
                },
                "isLldpEnabled": {
                "type": "boolean"
                },
                "reinitializationDelay": {
                "type": "integer"
                },
                "timer": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "lldpInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "adminStatus": {
                "enum": [
                "TRANSMIT_ONLY",
                "RECEIVE_ONLY",
                "TRANSMIT_AND_RECEIVE",
                "DISABLED"
                ],
                "type": "string"
                },
                "configType": {
                "enum": [
                "LLDP_INTERFACE"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "mabInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "MAB_INTERFACE"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "isMabEnabled": {
                "type": "boolean"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "mldSnoopingGlobalConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "MLD_SNOOPING_GLOBAL"
                ],
                "type": "string"
                },
                "isMldSnoopingEnabled": {
                "type": "boolean"
                },
                "isQuerierEnabled": {
                "type": "boolean"
                },
                "isSuppressListenerMessagesEnabled": {
                "type": "boolean"
                },
                "mldSnoopingVlanSettings": {
                "properties": {
                "configType": {
                "enum": [
                "SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "MLD_SNOOPING_VLAN"
                ],
                "type": "string"
                },
                "isImmediateLeaveEnabled": {
                "type": "boolean"
                },
                "isMldSnoopingEnabled": {
                "type": "boolean"
                },
                "isQuerierEnabled": {
                "type": "boolean"
                },
                "mldSnoopingVlanMrouters": {
                "properties": {
                "configType": {
                "enum": [
                "SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "MLD_SNOOPING_VLAN_MROUTER"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "querierAddress": {
                "type": "string"
                },
                "querierQueryInterval": {
                "type": "integer"
                },
                "querierVersion": {
                "enum": [
                "VERSION_1",
                "VERSION_2"
                ],
                "type": "string"
                },
                "vlanId": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "querierAddress": {
                "type": "string"
                },
                "querierQueryInterval": {
                "type": "integer"
                },
                "querierVersion": {
                "enum": [
                "VERSION_1",
                "VERSION_2"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "portChannelConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "PORTCHANNEL"
                ],
                "type": "string"
                },
                "isAutoEnabled": {
                "type": "boolean"
                },
                "lacpSystemPriority": {
                "type": "integer"
                },
                "loadBalancingMethod": {
                "enum": [
                "SRC_MAC",
                "DST_MAC",
                "SRC_DST_MAC",
                "SRC_IP",
                "DST_IP",
                "SRC_DST_IP",
                "SRC_PORT",
                "DST_PORT",
                "SRC_DST_PORT",
                "SRC_DST_MIXED_IP_PORT",
                "SRC_MIXED_IP_PORT",
                "DST_MIXED_IP_PORT",
                "VLAN_SRC_IP",
                "VLAN_DST_IP",
                "VLAN_SRC_DST_IP",
                "VLAN_SRC_MIXED_IP_PORT",
                "VLAN_DST_MIXED_IP_PORT",
                "VLAN_SRC_DST_MIXED_IP_PORT"
                ],
                "type": "string"
                },
                "portchannels": {
                "properties": {
                "configType": {
                "enum": [
                "SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "AnyOf": {
                "properties": {
                "EtherchannelConfig": {
                "properties": {
                "configType": {
                "enum": [
                "ETHERCHANNEL_CONFIG"
                ],
                "type": "string"
                },
                "memberPorts": {
                "properties": {
                "configType": {
                "enum": [
                "SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "ETHERCHANNEL_MEMBER_PORT_CONFIG"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "mode": {
                "enum": [
                "ON"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "minLinks": {
                "type": "integer"
                },
                "name": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "LacpPortchannelConfig": {
                "properties": {
                "configType": {
                "enum": [
                "LACP_PORTCHANNEL_CONFIG"
                ],
                "type": "string"
                },
                "memberPorts": {
                "properties": {
                "configType": {
                "enum": [
                "SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "LACP_PORTCHANNEL_MEMBER_PORT_CONFIG"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "mode": {
                "enum": [
                "ACTIVE",
                "PASSIVE"
                ],
                "type": "string"
                },
                "portPriority": {
                "type": "integer"
                },
                "rate": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "minLinks": {
                "type": "integer"
                },
                "name": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "PagpPortchannelConfig": {
                "properties": {
                "configType": {
                "enum": [
                "PAGP_PORTCHANNEL_CONFIG"
                ],
                "type": "string"
                },
                "memberPorts": {
                "properties": {
                "configType": {
                "enum": [
                "SET"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "PAGP_PORTCHANNEL_MEMBER_PORT_CONFIG"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "learnMethod": {
                "enum": [
                "AGGREGATION_PORT",
                "PHYSICAL_PORT"
                ],
                "type": "string"
                },
                "mode": {
                "enum": [
                "AUTO",
                "AUTO_NON_SILENT",
                "DESIRABLE",
                "DESIRABLE_NON_SILENT"
                ],
                "type": "string"
                },
                "portPriority": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "minLinks": {
                "type": "integer"
                },
                "name": {
                "type": "string"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "stpGlobalConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "STP_GLOBAL"
                ],
                "type": "string"
                },
                "isBackboneFastEnabled": {
                "type": "boolean"
                },
                "isBpduFilterEnabled": {
                "type": "boolean"
                },
                "isBpduGuardEnabled": {
                "type": "boolean"
                },
                "isEtherChannelGuardEnabled": {
                "type": "boolean"
                },
                "isExtendedSystemIdEnabled": {
                "type": "boolean"
                },
                "isLoggingEnabled": {
                "type": "boolean"
                },
                "isLoopGuardEnabled": {
                "type": "boolean"
                },
                "isUplinkFastEnabled": {
                "type": "boolean"
                },
                "portFastMode": {
                "enum": [
                "ENABLE",
                "DISABLE",
                "EDGE",
                "NETWORK"
                ],
                "type": "string"
                },
                "stpInstances": {
                "properties": {
                "configType": {
                "enum": [
                "LIST"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "STP_VLAN"
                ],
                "type": "string"
                },
                "priority": {
                "type": "integer"
                },
                "timers": {
                "properties": {
                "configType": {
                "enum": [
                "STP_TIMERS"
                ],
                "type": "string"
                },
                "forwardDelay": {
                "type": "integer"
                },
                "helloInterval": {
                "type": "integer"
                },
                "isStpEnabled": {
                "type": "boolean"
                },
                "maxAge": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "vlanId": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "stpMode": {
                "enum": [
                "PVST",
                "RSTP",
                "MST"
                ],
                "type": "string"
                },
                "transmitHoldCount": {
                "type": "integer"
                },
                "uplinkFastMaxUpdateRate": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "stpInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "properties": {
                "bpduFilter": {
                "enum": [
                "ENABLE",
                "DISABLE",
                "NONE"
                ],
                "type": "string"
                },
                "bpduGuard": {
                "enum": [
                "ENABLE",
                "DISABLE",
                "NONE"
                ],
                "type": "string"
                },
                "configType": {
                "enum": [
                "STP_INTERFACE"
                ],
                "type": "string"
                },
                "guardMode": {
                "enum": [
                "LOOP",
                "ROOT",
                "NONE"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "pathCost": {
                "type": "integer"
                },
                "portFastMode": {
                "enum": [
                "NONE",
                "DISABLE",
                "EDGE",
                "EDGE_TRUNK",
                "NETWORK",
                "TRUNK"
                ],
                "type": "string"
                },
                "portVlanCostSettings": {
                "properties": {
                "configType": {
                "enum": [
                "LIST"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "STP_INTERFACE_VLAN_COST"
                ],
                "type": "string"
                },
                "cost": {
                "type": "integer"
                },
                "vlans": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "portVlanPrioritySettings": {
                "properties": {
                "configType": {
                "enum": [
                "LIST"
                ],
                "type": "string"
                },
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "STP_INTERFACE_VLAN_PRIORITY"
                ],
                "type": "string"
                },
                "priority": {
                "type": "integer"
                },
                "vlans": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "priority": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "switchportInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "accessVlan": {
                "type": "integer"
                },
                "adminStatus": {
                "enum": [
                "UP",
                "DOWN"
                ],
                "type": "string"
                },
                "configType": {
                "enum": [
                "SWITCHPORT_INTERFACE"
                ],
                "type": "string"
                },
                "description":
                 {
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "mode": {
                "enum": [
                "ACCESS",
                "TRUNK",
                "DYNAMIC_AUTO",
                "DYNAMIC_DESIRABLE",
                "DOT1Q_TUNNEL"
                ],
                "type": "string"
                },
                "nativeVlan": {
                "type": "integer"
                },
                "trunkAllowedVlans": {
                "type": "string"
                },
                "voiceVlan": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "trunkInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "TRUNK_INTERFACE"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "isDtpNegotiationEnabled": {
                "type": "boolean"
                },
                "isProtected": {
                "type": "boolean"
                },
                "pruneEligibleVlans": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "vlanConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "VLAN"
                ],
                "type": "string"
                },
                "isVlanEnabled": {
                "type": "boolean"
                },
                "name": {
                "type": "string"
                },
                "vlanId": {
                "type": "integer"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "vtpGlobalConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "VTP_GLOBAL"
                ],
                "type": "string"
                },
                "configurationFileName": {
                "type": "string"
                },
                "domainName": {
                "type": "string"
                },
                "isPruningEnabled": {
                "type": "boolean"
                },
                "mode": {
                "enum": [
                "SERVER",
                "CLIENT",
                "TRANSPARENT",
                "OFF"
                ],
                "type": "string"
                },
                "sourceInterface": {
                "type": "string"
                },
                "version": {
                "enum": [
                "VERSION_1",
                "VERSION_2",
                "VERSION_3"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                },
                "vtpInterfaceConfig": {
                "properties": {
                "items": {
                "items": {
                "items": {
                "properties": {
                "configType": {
                "enum": [
                "VTP_INTERFACE"
                ],
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "isVtpEnabled": {
                "type": "boolean"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "type": "array"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )



# -*- coding: utf-8 -*-
"""Cisco Catalyst Center CreateRFProfile data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorBcb1D489D735258975828F845Df1769(object):
    """CreateRFProfile request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorBcb1D489D735258975828F845Df1769, self).__init__()
        self._validator = fastjsonschema.compile(json.loads('''
{
    "$schema": "http://json-schema.org/draft-04/schema#",
    "properties": {
        "defaultRfProfile": {
            "type": "boolean"
        },
        "enableRadioType6GHz": {
            "type": "boolean"
        },
        "enableRadioTypeA": {
            "type": "boolean"
        },
        "enableRadioTypeB": {
            "type": "boolean"
        },
        "radioType6GHzProperties": {
            "properties": {
                "broadcastProbeResponseInterval": {
                    "type": "integer"
                },
                "coverageHoleDetectionProperties": {
                    "properties": {
                        "chdClientLevel": {
                            "type": "integer"
                        },
                        "chdDataRssiThreshold": {
                            "type": "integer"
                        },
                        "chdExceptionLevel": {
                            "type": "integer"
                        },
                        "chdVoiceRssiThreshold": {
                            "type": "integer"
                        }
                    },
                    "type": "object"
                },
                "customRxSopThreshold": {
                    "type": "integer"
                },
                "dataRates": {
                    "type": "string"
                },
                "discoveryFrames6GHz": {
                    "enum": [
                        "None",
                        "Broadcast Probe Response",
                        "FILS Discovery"
                    ],
                    "type": "string"
                },
                "enableStandardPowerService": {
                    "type": "boolean"
                },
                "fraPropertiesC": {
                    "properties": {
                        "clientResetCount": {
                            "type": "integer"
                        },
                        "clientUtilizationThreshold": {
                            "type": "integer"
                        }
                    },
                    "type": "object"
                },
                "mandatoryDataRates": {
                    "type": "string"
                },
                "maxDbsWidth": {
                    "type": "integer"
                },
                "maxPowerLevel": {
                    "type": "integer"
                },
                "maxRadioClients": {
                    "type": "integer"
                },
                "minDbsWidth": {
                    "type": "integer"
                },
                "minPowerLevel": {
                    "type": "integer"
                },
                "multiBssidProperties": {
                    "properties": {
                        "dot11axParameters": {
                            "properties": {
                                "muMimoDownLink": {
                                    "type": "boolean"
                                },
                                "muMimoUpLink": {
                                    "type": "boolean"
                                },
                                "ofdmaDownLink": {
                                    "type": "boolean"
                                },
                                "ofdmaUpLink": {
                                    "type": "boolean"
                                }
                            },
                            "type": "object"
                        },
                        "dot11beParameters": {
                            "properties": {
                                "muMimoDownLink": {
                                    "type": "boolean"
                                },
                                "muMimoUpLink": {
                                    "type": "boolean"
                                },
                                "ofdmaDownLink": {
                                    "type": "boolean"
                                },
                                "ofdmaMultiRu": {
                                    "type": "boolean"
                                },
                                "ofdmaUpLink": {
                                    "type": "boolean"
                                }
                            },
                            "type": "object"
                        },
                        "targetWakeTime": {
                            "type": "boolean"
                        },
                        "twtBroadcastSupport": {
                            "type": "boolean"
                        }
                    },
                    "type": "object"
                },
                "parentProfile": {
                    "enum": [
                        "CUSTOM"
                    ],
                    "type": "string"
                },
                "powerThresholdV1": {
                    "type": "integer"
                },
                "preamblePuncture": {
                    "type": "boolean"
                },
                "pscEnforcingEnabled": {
                    "type": "boolean"
                },
                "radioChannels": {
                    "type": "string"
                },
                "rxSopThreshold": {
                    "enum": [
                        "HIGH",
                        "MEDIUM",
                        "LOW",
                        "AUTO",
                        "CUSTOM"
                    ],
                    "type": "string"
                },
                "spatialReuseProperties": {
                    "properties": {
                        "dot11axNonSrgObssPacketDetect": {
                            "type": "boolean"
                        },
                        "dot11axNonSrgObssPacketDetectMaxThreshold": {
                            "type": "integer"
                        },
                        "dot11axSrgObssPacketDetect": {
                            "type": "boolean"
                        },
                        "dot11axSrgObssPacketDetectMaxThreshold": {
                            "type": "integer"
                        },
                        "dot11axSrgObssPacketDetectMinThreshold": {
                            "type": "integer"
                        }
                    },
                    "type": "object"
                }
            },
            "type": "object"
        },
        "radioTypeAProperties": {
            "properties": {
                "channelWidth": {
                    "enum": [
                        "20",
                        "40",
                        "80",
                        "160",
                        "best"
                    ],
                    "type": "string"
                },
                "coverageHoleDetectionProperties": {
                    "properties": {
                        "chdClientLevel": {
                            "type": "integer"
                        },
                        "chdDataRssiThreshold": {
                            "type": "integer"
                        },
                        "chdExceptionLevel": {
                            "type": "integer"
                        },
                        "chdVoiceRssiThreshold": {
                            "type": "integer"
                        }
                    },
                    "type": "object"
                },
                "customRxSopThreshold": {
                    "type": "integer"
                },
                "dataRates": {
                    "type": "string"
                },
                "fraPropertiesA": {
                    "properties": {
                        "clientAware": {
                            "type": "boolean"
                        },
                        "clientReset": {
                            "type": "integer"
                        },
                        "clientSelect": {
                            "type": "integer"
                        }
                    },
                    "type": "object"
                },
                "mandatoryDataRates": {
                    "type": "string"
                },
                "maxPowerLevel": {
                    "type": "integer"
                },
                "maxRadioClients": {
                    "type": "integer"
                },
                "minPowerLevel": {
                    "type": "integer"
                },
                "parentProfile": {
                    "enum": [
                        "HIGH",
                        "TYPICAL",
                        "LOW",
                        "CUSTOM"
                    ],
                    "type": "string"
                },
                "powerThresholdV1": {
                    "type": "integer"
                },
                "preamblePuncture": {
                    "type": "boolean"
                },
                "radioChannels": {
                    "type": "string"
                },
                "rxSopThreshold": {
                    "enum": [
                        "HIGH",
                        "MEDIUM",
                        "LOW",
                        "AUTO",
                        "CUSTOM"
                    ],
                    "type": "string"
                },
                "spatialReuseProperties": {
                    "properties": {
                        "dot11axNonSrgObssPacketDetect": {
                            "type": "boolean"
                        },
                        "dot11axNonSrgObssPacketDetectMaxThreshold": {
                            "type": "integer"
                        },
                        "dot11axSrgObssPacketDetect": {
                            "type": "boolean"
                        },
                        "dot11axSrgObssPacketDetectMaxThreshold": {
                            "type": "integer"
                        },
                        "dot11axSrgObssPacketDetectMinThreshold": {
                            "type": "integer"
                        }
                    },
                    "type": "object"
                },
                "zeroWaitDfsEnable": {
                    "type": "boolean"
                }
            },
            "type": "object"
        },
        "radioTypeBProperties": {
            "properties": {
                "coverageHoleDetectionProperties": {
                    "properties": {
                        "chdClientLevel": {
                            "type": "integer"
                        },
                        "chdDataRssiThreshold": {
                            "type": "integer"
                        },
                        "chdExceptionLevel": {
                            "type": "integer"
                        },
                        "chdVoiceRssiThreshold": {
                            "type": "integer"
                        }
                    },
                    "type": "object"
                },
                "customRxSopThreshold": {
                    "type": "integer"
                },
                "dataRates": {
                    "type": "string"
                },
                "mandatoryDataRates": {
                    "type": "string"
                },
                "maxPowerLevel": {
                    "type": "integer"
                },
                "maxRadioClients": {
                    "type": "integer"
                },
                "minPowerLevel": {
                    "type": "integer"
                },
                "parentProfile": {
                    "enum": [
                        "HIGH",
                        "TYPICAL",
                        "LOW",
                        "CUSTOM"
                    ],
                    "type": "string"
                },
                "powerThresholdV1": {
                    "type": "integer"
                },
                "radioChannels": {
                    "type": "string"
                },
                "rxSopThreshold": {
                    "enum": [
                        "HIGH",
                        "MEDIUM",
                        "LOW",
                        "AUTO",
                        "CUSTOM"
                    ],
                    "type": "string"
                },
                "spatialReuseProperties": {
                    "properties": {
                        "dot11axNonSrgObssPacketDetect": {
                            "type": "boolean"
                        },
                        "dot11axNonSrgObssPacketDetectMaxThreshold": {
                            "type": "integer"
                        },
                        "dot11axSrgObssPacketDetect": {
                            "type": "boolean"
                        },
                        "dot11axSrgObssPacketDetectMaxThreshold": {
                            "type": "integer"
                        },
                        "dot11axSrgObssPacketDetectMinThreshold": {
                            "type": "integer"
                        }
                    },
                    "type": "object"
                }
            },
            "type": "object"
        },
        "rfProfileName": {
            "type": "string"
        }
    },
    "type": "object"
}
'''))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )



# -*- coding: utf-8 -*-
"""Cisco Catalyst Center CreateNetworkV2 data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorC5F97865727857D5B1EeAedee3Dcccd2(object):
    """CreateNetworkV2 request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorC5F97865727857D5B1EeAedee3Dcccd2, self).__init__()
        self._validator = fastjsonschema.compile(json.loads('''
{
    "$schema": "http://json-schema.org/draft-04/schema#",
    "properties": {
        "settings": {
            "properties": {
                "clientAndEndpoint_aaa": {
                    "properties": {
                        "ipAddress": {
                            "type": "string"
                        },
                        "network": {
                            "type": "string"
                        },
                        "protocol": {
                            "type": "string"
                        },
                        "servers": {
                            "type": "string"
                        },
                        "sharedSecret": {
                            "type": "string"
                        }
                    },
                    "type": "object"
                },
                "dhcpServer": {
                    "items": {
                        "type": "string"
                    },
                    "type": "array"
                },
                "dnsServer": {
                    "properties": {
                        "domainName": {
                            "type": "string"
                        },
                        "primaryIpAddress": {
                            "type": "string"
                        },
                        "secondaryIpAddress": {
                            "type": "string"
                        }
                    },
                    "type": "object"
                },
                "messageOfTheday": {
                    "properties": {
                        "bannerMessage": {
                            "type": "string"
                        },
                        "retainExistingBanner": {
                            "type": "string"
                        }
                    },
                    "type": "object"
                },
                "netflowcollector": {
                    "properties": {
                        "ipAddress": {
                            "type": "string"
                        },
                        "port": {
                            "type": "number"
                        }
                    },
                    "type": "object"
                },
                "network_aaa": {
                    "properties": {
                        "ipAddress": {
                            "type": "string"
                        },
                        "network": {
                            "type": "string"
                        },
                        "protocol": {
                            "type": "string"
                        },
                        "servers": {
                            "type": "string"
                        },
                        "sharedSecret": {
                            "type": "string"
                        }
                    },
                    "type": "object"
                },
                "ntpServer": {
                    "items": {
                        "type": "string"
                    },
                    "type": "array"
                },
                "snmpServer": {
                    "properties": {
                        "configureDnacIP": {
                            "type": "boolean"
                        },
                        "ipAddresses": {
                            "items": {
                                "type": "string"
                            },
                            "type": "array"
                        }
                    },
                    "type": "object"
                },
                "syslogServer": {
                    "properties": {
                        "configureDnacIP": {
                            "type": "boolean"
                        },
                        "ipAddresses": {
                            "items": {
                                "type": "string"
                            },
                            "type": "array"
                        }
                    },
                    "type": "object"
                },
                "timezone": {
                    "type": "string"
                }
            },
            "type": "object"
        }
    },
    "type": "object"
}
'''))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
